# -*- coding: utf-8 -*-
#CPE 1704 TKS
"""
Standard Manupilation modules that are not directly UI based.
"""
from PIL import Image
from PyQt4.QtCore import pyqtSignature
from filters.toolbox import *
from filters.display import *

def Adjust_ColorLevel(self, imageToEdit, UpdateRealImage):

    if DisplayWait_Enable(self,  UpdateRealImage):
        im = imageToEdit
        source = im.split()
        R, G, B = 0, 1, 2

        if self.core.valR <> 0:
            out = source[R].point(lambda i: i *valToScalar(self.core.valR))
            source[R].paste(out, None, None)

        if self.core.valG <> 0:
            out = source[G].point(lambda i: i *valToScalar(self.core.valG))
            source[G].paste(out, None, None)

        if self.core.valB <> 0:
            out = source[B].point(lambda i: i *valToScalar(self.core.valB))
            source[B].paste(out, None, None)

        im = Image.merge(im.mode, source)

        DisplayWait_Disable(self,  UpdateRealImage,  im)

def ColorLevelReset(self):
    """
    Slot documentation goes here.
    """
    self.cSlide_R.setValue(0)
    self.cSlide_G.setValue(0)
    self.cSlide_B.setValue(0)
    self.LevelApply(self.core.curThumb,  False)
    self.LevelApply(self.core.curIm,  True)
    FullScreenToggle(self, True, 1)
